==> google-cloud-video-live-stream-0.1.0.tar.gz: google-cloud-video-live-stream-0.1.0/google/cloud/video/live_stream_v1/services/livestream_service/transports/base.py <==
# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import abc
from typing import Awaitable, Callable, Dict, Optional, Sequence, Union
import pkg_resources

import google.auth  # type: ignore
import google.api_core
from google.api_core import exceptions as core_exceptions
from google.api_core import gapic_v1
from google.api_core import retry as retries
from google.api_core import operations_v1
from google.auth import credentials as ga_credentials  # type: ignore
from google.oauth2 import service_account  # type: ignore

from google.cloud.video.live_stream_v1.types import resources
from google.cloud.video.live_stream_v1.types import service
from google.longrunning import operations_pb2  # type: ignore
from google.protobuf import empty_pb2  # type: ignore

try:
    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
        gapic_version=pkg_resources.get_distribution(
            "google-cloud-video-live-stream",
        ).version,
    )
except pkg_resources.DistributionNotFound:
    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()


class LivestreamServiceTransport(abc.ABC):
    """Abstract transport class for LivestreamService."""

    AUTH_SCOPES = ("https://www.googleapis.com/auth/cloud-platform",)

    DEFAULT_HOST: str = "livestream.googleapis.com"

    def __init__(
        self,
        *,
        host: str = DEFAULT_HOST,
        credentials: ga_credentials.Credentials = None,
        credentials_file: Optional[str] = None,
        scopes: Optional[Sequence[str]] = None,
        quota_project_id: Optional[str] = None,
        client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
        always_use_jwt_access: Optional[bool] = False,
        **kwargs,
    ) -> None:
        """Instantiate the transport.

        Args:
            host (Optional[str]):
                 The hostname to connect to.
            credentials (Optional[google.auth.credentials.Credentials]): The
                authorization credentials to attach to requests. These
                credentials identify the application to the service; if none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
            credentials_file (Optional[str]): A file with credentials that can
                be loaded with :func:`google.auth.load_credentials_from_file`.
                This argument is mutually exclusive with credentials.
            scopes (Optional[Sequence[str]]): A list of scopes.
            quota_project_id (Optional[str]): An optional project to use for billing
                and quota.
            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
                The client info used to send a user-agent string along with
                API requests. If ``None``, then default info will be used.
                Generally, you only need to set this if you're developing
                your own client library.
            always_use_jwt_access (Optional[bool]): Whether self signed JWT should
                be used for service account credentials.
        """
        # Save the hostname. Default to port 443 (HTTPS) if none is specified.
        if ":" not in host:
            host += ":443"
        self._host = host

        scopes_kwargs = {"scopes": scopes, "default_scopes": self.AUTH_SCOPES}

        # Save the scopes.
        self._scopes = scopes

        # If no credentials are provided, then determine the appropriate
        # defaults.
        if credentials and credentials_file:
            raise core_exceptions.DuplicateCredentialArgs(
                "'credentials_file' and 'credentials' are mutually exclusive"
            )

        if credentials_file is not None:
            credentials, _ = google.auth.load_credentials_from_file(
                credentials_file, **scopes_kwargs, quota_project_id=quota_project_id
            )
        elif credentials is None:
            credentials, _ = google.auth.default(
                **scopes_kwargs, quota_project_id=quota_project_id
            )

        # If the credentials are service account credentials, then always try to use self signed JWT.
        if (
            always_use_jwt_access
            and isinstance(credentials, service_account.Credentials)
            and hasattr(service_account.Credentials, "with_always_use_jwt_access")
        ):
            credentials = credentials.with_always_use_jwt_access(True)

        # Save the credentials.
        self._credentials = credentials

    def _prep_wrapped_messages(self, client_info):
        # Precompute the wrapped methods.
        self._wrapped_methods = {
            self.create_channel_: gapic_v1.method.wrap_method(
                self.create_channel_, default_timeout=60.0, client_info=client_info,
            ),
            self.list_channels: gapic_v1.method.wrap_method(
                self.list_channels,
                default_retry=retries.Retry(
                    initial=1.0,
                    maximum=10.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.get_channel: gapic_v1.method.wrap_method(
                self.get_channel,
                default_retry=retries.Retry(
                    initial=1.0,
                    maximum=10.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.delete_channel: gapic_v1.method.wrap_method(
                self.delete_channel, default_timeout=60.0, client_info=client_info,
            ),
            self.update_channel: gapic_v1.method.wrap_method(
                self.update_channel, default_timeout=60.0, client_info=client_info,
            ),
            self.start_channel: gapic_v1.method.wrap_method(
                self.start_channel, default_timeout=60.0, client_info=client_info,
            ),
            self.stop_channel: gapic_v1.method.wrap_method(
                self.stop_channel, default_timeout=60.0, client_info=client_info,
            ),
            self.create_input: gapic_v1.method.wrap_method(
                self.create_input, default_timeout=60.0, client_info=client_info,
            ),
            self.list_inputs: gapic_v1.method.wrap_method(
                self.list_inputs,
                default_retry=retries.Retry(
                    initial=1.0,
                    maximum=10.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.get_input: gapic_v1.method.wrap_method(
                self.get_input,
                default_retry=retries.Retry(
                    initial=1.0,
                    maximum=10.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.delete_input: gapic_v1.method.wrap_method(
                self.delete_input, default_timeout=60.0, client_info=client_info,
            ),
            self.update_input: gapic_v1.method.wrap_method(
                self.update_input, default_timeout=60.0, client_info=client_info,
            ),
            self.create_event: gapic_v1.method.wrap_method(
                self.create_event, default_timeout=60.0, client_info=client_info,
            ),
            self.list_events: gapic_v1.method.wrap_method(
                self.list_events,
                default_retry=retries.Retry(
                    initial=1.0,
                    maximum=10.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.get_event: gapic_v1.method.wrap_method(
                self.get_event,
                default_retry=retries.Retry(
                    initial=1.0,
                    maximum=10.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.delete_event: gapic_v1.method.wrap_method(
                self.delete_event, default_timeout=60.0, client_info=client_info,
            ),
        }

    def close(self):
        """Closes resources associated with the transport.

       .. warning::
            Only call this method if the transport is NOT shared
            with other clients - this may cause errors in other clients!
        """
        raise NotImplementedError()

    @property
    def operations_client(self):
        """Return the client designed to process long-running operations."""
        raise NotImplementedError()

    @property
    def create_channel_(
        self,
    ) -> Callable[
        [service.CreateChannelRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def list_channels(
        self,
    ) -> Callable[
        [service.ListChannelsRequest],
        Union[service.ListChannelsResponse, Awaitable[service.ListChannelsResponse]],
    ]:
        raise NotImplementedError()

    @property
    def get_channel(
        self,
    ) -> Callable[
        [service.GetChannelRequest],
        Union[resources.Channel, Awaitable[resources.Channel]],
    ]:
        raise NotImplementedError()

    @property
    def delete_channel(
        self,
    ) -> Callable[
        [service.DeleteChannelRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def update_channel(
        self,
    ) -> Callable[
        [service.UpdateChannelRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def start_channel(
        self,
    ) -> Callable[
        [service.StartChannelRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def stop_channel(
        self,
    ) -> Callable[
        [service.StopChannelRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def create_input(
        self,
    ) -> Callable[
        [service.CreateInputRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def list_inputs(
        self,
    ) -> Callable[
        [service.ListInputsRequest],
        Union[service.ListInputsResponse, Awaitable[service.ListInputsResponse]],
    ]:
        raise NotImplementedError()

    @property
    def get_input(
        self,
    ) -> Callable[
        [service.GetInputRequest], Union[resources.Input, Awaitable[resources.Input]]
    ]:
        raise NotImplementedError()

    @property
    def delete_input(
        self,
    ) -> Callable[
        [service.DeleteInputRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def update_input(
        self,
    ) -> Callable[
        [service.UpdateInputRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def create_event(
        self,
    ) -> Callable[
        [service.CreateEventRequest], Union[resources.Event, Awaitable[resources.Event]]
    ]:
        raise NotImplementedError()

    @property
    def list_events(
        self,
    ) -> Callable[
        [service.ListEventsRequest],
        Union[service.ListEventsResponse, Awaitable[service.ListEventsResponse]],
    ]:
        raise NotImplementedError()

    @property
    def get_event(
        self,
    ) -> Callable[
        [service.GetEventRequest], Union[resources.Event, Awaitable[resources.Event]]
    ]:
        raise NotImplementedError()

    @property
    def delete_event(
        self,
    ) -> Callable[
        [service.DeleteEventRequest], Union[empty_pb2.Empty, Awaitable[empty_pb2.Empty]]
    ]:
        raise NotImplementedError()


__all__ = ("LivestreamServiceTransport",)

==> google-cloud-video-live-stream-0.1.4.tar.gz: google-cloud-video-live-stream-0.1.4/google/cloud/video/live_stream_v1/services/livestream_service/transports/base.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import abc
from typing import Awaitable, Callable, Dict, Optional, Sequence, Union

import google.api_core
from google.api_core import exceptions as core_exceptions
from google.api_core import gapic_v1, operations_v1
from google.api_core import retry as retries
import google.auth  # type: ignore
from google.auth import credentials as ga_credentials  # type: ignore
from google.longrunning import operations_pb2  # type: ignore
from google.oauth2 import service_account  # type: ignore
from google.protobuf import empty_pb2  # type: ignore
import pkg_resources

from google.cloud.video.live_stream_v1.types import resources, service

try:
    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
        gapic_version=pkg_resources.get_distribution(
            "google-cloud-video-live-stream",
        ).version,
    )
except pkg_resources.DistributionNotFound:
    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()


class LivestreamServiceTransport(abc.ABC):
    """Abstract transport class for LivestreamService."""

    AUTH_SCOPES = ("https://www.googleapis.com/auth/cloud-platform",)

    DEFAULT_HOST: str = "livestream.googleapis.com"

    def __init__(
        self,
        *,
        host: str = DEFAULT_HOST,
        credentials: ga_credentials.Credentials = None,
        credentials_file: Optional[str] = None,
        scopes: Optional[Sequence[str]] = None,
        quota_project_id: Optional[str] = None,
        client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
        always_use_jwt_access: Optional[bool] = False,
        **kwargs,
    ) -> None:
        """Instantiate the transport.

        Args:
            host (Optional[str]):
                 The hostname to connect to.
            credentials (Optional[google.auth.credentials.Credentials]): The
                authorization credentials to attach to requests. These
                credentials identify the application to the service; if none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
            credentials_file (Optional[str]): A file with credentials that can
                be loaded with :func:`google.auth.load_credentials_from_file`.
                This argument is mutually exclusive with credentials.
            scopes (Optional[Sequence[str]]): A list of scopes.
            quota_project_id (Optional[str]): An optional project to use for billing
                and quota.
            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
                The client info used to send a user-agent string along with
                API requests. If ``None``, then default info will be used.
                Generally, you only need to set this if you're developing
                your own client library.
            always_use_jwt_access (Optional[bool]): Whether self signed JWT should
                be used for service account credentials.
        """

        # Save the hostname. Default to port 443 (HTTPS) if none is specified.
        if ":" not in host:
            host += ":443"
        self._host = host

        scopes_kwargs = {"scopes": scopes, "default_scopes": self.AUTH_SCOPES}

        # Save the scopes.
        self._scopes = scopes

        # If no credentials are provided, then determine the appropriate
        # defaults.
        if credentials and credentials_file:
            raise core_exceptions.DuplicateCredentialArgs(
                "'credentials_file' and 'credentials' are mutually exclusive"
            )

        if credentials_file is not None:
            credentials, _ = google.auth.load_credentials_from_file(
                credentials_file, **scopes_kwargs, quota_project_id=quota_project_id
            )
        elif credentials is None:
            credentials, _ = google.auth.default(
                **scopes_kwargs, quota_project_id=quota_project_id
            )

        # If the credentials are service account credentials, then always try to use self signed JWT.
        if (
            always_use_jwt_access
            and isinstance(credentials, service_account.Credentials)
            and hasattr(service_account.Credentials, "with_always_use_jwt_access")
        ):
            credentials = credentials.with_always_use_jwt_access(True)

        # Save the credentials.
        self._credentials = credentials

    def _prep_wrapped_messages(self, client_info):
        # Precompute the wrapped methods.
        self._wrapped_methods = {
            self.create_channel_: gapic_v1.method.wrap_method(
                self.create_channel_,
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.list_channels: gapic_v1.method.wrap_method(
                self.list_channels,
                default_retry=retries.Retry(
                    initial=1.0,
                    maximum=10.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.get_channel: gapic_v1.method.wrap_method(
                self.get_channel,
                default_retry=retries.Retry(
                    initial=1.0,
                    maximum=10.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.delete_channel: gapic_v1.method.wrap_method(
                self.delete_channel,
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.update_channel: gapic_v1.method.wrap_method(
                self.update_channel,
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.start_channel: gapic_v1.method.wrap_method(
                self.start_channel,
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.stop_channel: gapic_v1.method.wrap_method(
                self.stop_channel,
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.create_input: gapic_v1.method.wrap_method(
                self.create_input,
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.list_inputs: gapic_v1.method.wrap_method(
                self.list_inputs,
                default_retry=retries.Retry(
                    initial=1.0,
                    maximum=10.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.get_input: gapic_v1.method.wrap_method(
                self.get_input,
                default_retry=retries.Retry(
                    initial=1.0,
                    maximum=10.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.delete_input: gapic_v1.method.wrap_method(
                self.delete_input,
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.update_input: gapic_v1.method.wrap_method(
                self.update_input,
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.create_event: gapic_v1.method.wrap_method(
                self.create_event,
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.list_events: gapic_v1.method.wrap_method(
                self.list_events,
                default_retry=retries.Retry(
                    initial=1.0,
                    maximum=10.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.get_event: gapic_v1.method.wrap_method(
                self.get_event,
                default_retry=retries.Retry(
                    initial=1.0,
                    maximum=10.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.delete_event: gapic_v1.method.wrap_method(
                self.delete_event,
                default_timeout=60.0,
                client_info=client_info,
            ),
        }

    def close(self):
        """Closes resources associated with the transport.

        .. warning::
             Only call this method if the transport is NOT shared
             with other clients - this may cause errors in other clients!
        """
        raise NotImplementedError()

    @property
    def operations_client(self):
        """Return the client designed to process long-running operations."""
        raise NotImplementedError()

    @property
    def create_channel_(
        self,
    ) -> Callable[
        [service.CreateChannelRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def list_channels(
        self,
    ) -> Callable[
        [service.ListChannelsRequest],
        Union[service.ListChannelsResponse, Awaitable[service.ListChannelsResponse]],
    ]:
        raise NotImplementedError()

    @property
    def get_channel(
        self,
    ) -> Callable[
        [service.GetChannelRequest],
        Union[resources.Channel, Awaitable[resources.Channel]],
    ]:
        raise NotImplementedError()

    @property
    def delete_channel(
        self,
    ) -> Callable[
        [service.DeleteChannelRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def update_channel(
        self,
    ) -> Callable[
        [service.UpdateChannelRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def start_channel(
        self,
    ) -> Callable[
        [service.StartChannelRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def stop_channel(
        self,
    ) -> Callable[
        [service.StopChannelRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def create_input(
        self,
    ) -> Callable[
        [service.CreateInputRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def list_inputs(
        self,
    ) -> Callable[
        [service.ListInputsRequest],
        Union[service.ListInputsResponse, Awaitable[service.ListInputsResponse]],
    ]:
        raise NotImplementedError()

    @property
    def get_input(
        self,
    ) -> Callable[
        [service.GetInputRequest], Union[resources.Input, Awaitable[resources.Input]]
    ]:
        raise NotImplementedError()

    @property
    def delete_input(
        self,
    ) -> Callable[
        [service.DeleteInputRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def update_input(
        self,
    ) -> Callable[
        [service.UpdateInputRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def create_event(
        self,
    ) -> Callable[
        [service.CreateEventRequest], Union[resources.Event, Awaitable[resources.Event]]
    ]:
        raise NotImplementedError()

    @property
    def list_events(
        self,
    ) -> Callable[
        [service.ListEventsRequest],
        Union[service.ListEventsResponse, Awaitable[service.ListEventsResponse]],
    ]:
        raise NotImplementedError()

    @property
    def get_event(
        self,
    ) -> Callable[
        [service.GetEventRequest], Union[resources.Event, Awaitable[resources.Event]]
    ]:
        raise NotImplementedError()

    @property
    def delete_event(
        self,
    ) -> Callable[
        [service.DeleteEventRequest], Union[empty_pb2.Empty, Awaitable[empty_pb2.Empty]]
    ]:
        raise NotImplementedError()

    @property
    def kind(self) -> str:
        raise NotImplementedError()


__all__ = ("LivestreamServiceTransport",)
